@@ -24,6 +24,13 @@ try:
     from .redirection import *
     from .pivotal_framework import *
     from .utterance_simulator import *
+except ModuleNotFoundError as e:
+    # Don't print ModuleNotFoundError messages as they're handled by individual modules
+    if "not currently installed" not in str(e):
+        print(f"An error occurred: {e}")
+        warnings.warn(
+            "If you are using ConvoKit with Google Colab, incorrect versions of some packages (ex. scipy) may be imported while runtime start. To fix the issue, restart the session and run all codes again. Thank you!"
+        )
 except Exception as e:
     print(f"An error occurred: {e}")
     warnings.warn(
